/******************************************************************************
 *
 *			EnviroNet Firmware Version 1.0
 *
 ******************************************************************************
 * FileName:        ascii_hex_service.c
 * Dependencies:    See INCLUDES section below
 * Processor:       PIC24
 * Compiler:        MPLAB C30
 * Company:         GrayStone Industries
 *
 * Author               Date        Comment
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 * Roger Bishop         2/1/11      Revision A.
 ******************************************************************************/

/*
Notes:

*/


//Includes
#include "constants.h"


//Fuses


//Variables


//Private Prototypes
 

//Declarations


/******************************************************************************
 Function:        	unsigned char Convert_Ascii_to_Hex (unsigned char *buffer_pointer)
 Precondition:    	None
 Input:           	None
 Output:         	None
 Side Effects:    	None
 Description:       Convert ASCII characters to HEX byte
 *****************************************************************************/
unsigned char Convert_Ascii_to_Hex (unsigned char *buffer_pointer)
{
	unsigned char index1;
	//BOOL communication_error = FALSE;
	unsigned char hex_byte = NULL;
	unsigned char nibble_extent = (BYTE_SIZE / 4);
	unsigned char nibble_offset = 4;
	unsigned char hex_nibble [nibble_extent];
	
	for (index1 = 0; index1 <= (nibble_extent - 1); index1 ++)
	{
		hex_nibble [index1] = *(buffer_pointer + index1);
		//convert all received ASCII alpha characters to upper case
		if ((hex_nibble [index1] >= 'a') && (hex_nibble [index1] <= 'z'))
			hex_nibble [index1] = (char)toupper((int)hex_nibble [index1]);
		//check that a hex nibble is possibly being sent (i.e 0x0 (= 0x30 for '0') to 0xF (= 0x46 for 'F')
		if (((hex_nibble [index1] >= 'A') && (hex_nibble [index1] <= 'F')) || ((hex_nibble [index1] >= '0') && (hex_nibble [index1] <= '9')))
		{
			//convert nibble
			if ((hex_nibble [index1] >= 'A') && (hex_nibble [index1] <= 'F'))
				hex_nibble [index1] = hex_nibble [index1] - 0x37;
			else
				hex_nibble [index1] = hex_nibble [index1] - 0x30;
		}
		//if not a hex nibble attempting conversion, then set error and break
		else
		{
			//communication_error = TRUE;
			break;
		}
	}
/*
	if (communication_error == FALSE)
	{
		hex_byte = hex_nibble [0];
		hex_byte <<= nibble_offset;
		hex_byte |= hex_nibble [1];
	}
	else
		hex_byte = COMMUNICATION_ERROR;
*/
	return hex_byte;
}	
//end Convert_Ascii_To_Hex


/******************************************************************************
 Function:        	char *Convert_Hex_to_Ascii (unsigned char hex_byte)
 Precondition:    	None
 Input:           	None
 Output:         	None
 Side Effects:    	None
 Description:       Convert HEX characters to ASCII byte
 *****************************************************************************/
char *Convert_Hex_to_Ascii (unsigned char hex_byte)
{
	char buffer_pointer [2];
	unsigned char hex_nibble [2];
	unsigned char index1;
	
	//high nibble of byte
	hex_nibble [0] = (hex_byte & 0xF0) >> 4;
	//low nibble of byte
	hex_nibble [1] = hex_byte & 0x0F;
	
	for (index1 = 0; index1 <= 1; index1 ++)
	{
		//convert nibbles to ASCII representations
		if ((hex_nibble [index1] >= 0x00) && ( hex_nibble [index1] <= 0x09))
			buffer_pointer [index1] = hex_nibble [index1] + 0x30;
		else
			buffer_pointer [index1] = hex_nibble [index1] + 0x37;
	}
	Nop();
	Nop();				
	Nop();
	Nop();
	return &buffer_pointer;
}
//end Convert_Hex_to_Ascii

//========== end ascii_hex_service.c ==========
