#ifndef __COMPARATOR_H /* COMPARATOR_H */
#define __COMPARATOR_H

 /*****************************************************************************
 *       COMPARATOR PERIPHERAL LIBRARY HEADER FILE
 ******************************************************************************
 * FileName:        comparator.h
 * Dependencies:    See include below
 * Processor:       PIC24
 * Compiler:        MPLAB C30
 * Company:         Microchip Technology, Inc.
 *
 * Software License Agreement
 * The software supplied herewith by Microchip Technology Incorporated
 * (the Company) for its PICmicro Microcontroller is intended and
 * supplied to you, the Companys customer, for use solely and
 * exclusively on Microchip PICmicro Microcontroller products. The
 * software is owned by the Company and/or its supplier, and is
 * protected under applicable copyright laws. All rights are reserved.
 * Any use in violation of the foregoing restrictions may subject the
 * user to criminal sanctions under applicable laws, as well as to
 * civil liability for the breach of the terms and conditions of this
 * license.
 *
 * THIS SOFTWARE IS PROVIDED IN AN AS IS CONDITION. NO WARRANTIES,
 * WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED
 * TO, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE APPLY TO THIS SOFTWARE. THE COMPANY SHALL NOT,
 * IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL OR
 * CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *
 *****************************************************************************/

#include "PIC24F_periph_features.h"

//This preprocessor conditional statement is to avoid unintended linking for unsuppported devices.
#if defined (cmp_v1_1) || defined (cmp_v2_1) || defined (cmp_v2_2) || defined (cmp_v2_3) ||\
	defined (cmp_v2_4) || defined (cmp_v2_5) ||defined (LIB_BUILD)

#if defined (cmp_v1_1) 
/*Registers Defaults*/
#define COMP_CVRCON_VAL    				0x0000
#define COMP_CMCON_VAL     				0x0000

/*CMCON register definition*/
#define CMP_IDLE_STOP               	0x8000 /* When device enters Idle mode, module does notgenerate interrupts.Module is still enabled. */
#define CMP_IDLE_CON                	0x0000 /* continue operation in idle mode */
#define CMP_IDLE_MASK               	(~CMP_IDLE_STOP)

#define CMP2_CHANGE_STATE           	0x2000 /* Comparator output changed states */
#define CMP2_NO_CHANGE             	 	0x0000 /* Comparator output did not change states */
#define CMP2_STATE_MASK             	(~CMP2_CHANGE_STATE )

#define CMP1_CHANGE_STATE           	0x1000 /* Comparator output changed states */
#define CMP1_NO_CHANGE              	0x0000 /* Comparator output did not change states */
#define CMP1_ENBL_DSBL_MASK         	(~CMP1_CHANGE_STATE )

#define CMP2_ENABLE                 	0x0800 /* Comparator is enabled */
#define CMP2_DISABLE                	0x0000 /* Comparator is disabled */
#define CMP2_ENBL_DSBL_MASK         	(~CMP2_ENABLE)

#define CMP1_ENABLE                 	0x0400 /* Comparator is enabled */
#define CMP1_DISABLE                	0x0000 /* Comparator is disabled */
#define CMP1_STATE_MASK             	(~CMP1_ENABLE)

#define CMP2_OUTPUT_ENABLE          	0x0200 /* Comparator output driven on the output pad */
#define CMP2_OUTPUT_DISABLE         	0x0000 /* Comparator output is not driven on the output pad */
#define CMP2_OUTPUT_MASK            	(~CMP2_OUTPUT_ENABLE)

#define CMP1_OUTPUT_ENABLE          	0x0100 /* Comparator output driven on the output pad */
#define CMP1_OUTPUT_DISABLE         	0x0000 /* Comparator output is not driven on the output pad */
#define CMP1_OUTPUT_MASK            	(~CMP1_OUTPUT_ENABLE)

#define CMP2_INV_OUTPUT             	0x0020 /* C2 output inverted */
#define CMP2_NORMAL_OUTPUT          	0x0000 /* C2 output not inverted */
#define CMP2_INV_OUTPUT_MASK        	(~CMP2_INV_OUTPUT)

#define CMP1_INV_OUTPUT             	0x0010 /* C1 output inverted */
#define CMP1_NORMAL_OUTPUT          	0x0000 /* C1 output not inverted */
#define CMP1_INV_OUTPUT_MASK        	(~CMP1_INV_OUTPUT)

#define CMP2_NEG_IP_Vin_Pos        		0x0008 /* Input is connected to Vin+ */
#define CMP2_NEG_IP_Vin_Neg        		0x0000 /* Input is connected to Vin- */
#define CMP2_NEG_IP_MASK           		(~CMP2_NEG_IP_Vin_Pos)

#define CMP2_POS_IP_Vin_Pos        		0x0004 /* Input is connected to Vin+ */
#define CMP2_POS_IP_CV_Ref         		0x0000 /* Input is connected to Vin- */
#define CMP2_POS_IP_MASK           		(~CMP2_POS_IP_Vin_Pos)

#define CMP1_NEG_IP_Vin_Pos        		0x0002 /* Input is connected to Vin+ */
#define CMP1_NEG_IP_Vin_Neg        		0x0000 /* Input is connected to Vin- */
#define CMP1_NEG_IP_MASK           		(~CMP1_NEG_IP_Vin_Pos)

#define CMP1_POS_IP_Vin_Pos        		0x0001 /* Input is connected to Vin+ */
#define CMP1_POS_IP_CV_Ref         		0x0000 /* Input is connected to Vin- */
#define CMP1_POS_IP_MASK           		(~CMP1_POS_IP_Vin_Pos)

/*CVRCON register definition*/
#define CMP_VRef_Enable            		0x0080 /* CVREF circuit powered on */
#define CMP_VRef_Disable           		0x0000 /* CVREF circuit powered down */
#define CMP_VRef_MASK             		(~CMP_VRef_Enable)

#define CMP_VRef_OUTPUT_Enable     		0x0040 /* CVREF voltage level is output on CVREF pin */
#define CMP_VRef_OUTPUT_Disable    		0x0000 /* CVREF voltage level is disconnected from CVREF pin */
#define CMP_VRef_OUTPUT_MASK       		(~CMP_VRef_OUTPUT_Enable)

#define CMP_VRef_SELECT_24_STEPS   		0x0020 /* 0 to 0.67 CVRSRC, with CVRSRC/24 step size */
#define CMP_VRef_SELECT_32_STEPS   		0x0000 /* 0.25 CVRSRC to 0.75 CVRSRC, with CVRSRC/32 step size */
#define CMP_VRef_STEP_SELECT_MASK  		(~CMP_VRef_SELECT_24_STEPS)

#define CMP_Vrsrc_Vref_Vref        		0x0010 /* Comparator reference source CVRSRC = VREF+  VREF- */
#define CMP_Vrsrc_AVDD_AVSS        		0x0000 /* Comparator reference source CVRSRC = AVDD  AVSS */
#define CMP_Vrsrc_MASK             		(~CMP_Vrsrc_Vref_Vref)

#define CMP_0p0CVrsrc_OR_0p25CVrsrc      0x0000 /* 0 CVRSRC with CVRSRC/24 step size, 0.25 CVRSRC with CVRSRC/32 step size */
#define CMP_0p04CVrsrc_OR_0p28CVrsrc     0x0001 /* 0.40 CVRSRC with CVRSRC/24 step size, 0.28 CVRSRC with CVRSRC/32 step size */
#define CMP_0p08CVrsrc_OR_0p31CVrsrc     0x0002 /* 0.80 CVRSRC with CVRSRC/24 step size, 0.31 CVRSRC with CVRSRC/32 step size */
#define CMP_0p12CVrsrc_OR_0p34CVrsrc     0x0003 /* 0.12 CVRSRC with CVRSRC/24 step size, 0.34 CVRSRC with CVRSRC/32 step size */
#define CMP_0p16CVrsrc_OR_0p37CVrsrc     0x0004 /* 0.16 CVRSRC with CVRSRC/24 step size, 0.37 CVRSRC with CVRSRC/32 step size */
#define CMP_0p20CVrsrc_OR_0p40CVrsrc     0x0005 /* 0.20 CVRSRC with CVRSRC/24 step size, 0.40 CVRSRC with CVRSRC/32 step size */
#define CMP_0p25CVrsrc_OR_0p43CVrsrc     0x0006 /* 0.25 CVRSRC with CVRSRC/24 step size, 0.43 CVRSRC with CVRSRC/32 step size */
#define CMP_0p29CVrsrc_OR_0p46CVrsrc     0x0007 /* 0.29 CVRSRC with CVRSRC/24 step size, 0.46 CVRSRC with CVRSRC/32 step size */
#define CMP_0p33CVrsrc_OR_0p50CVrsrc     0x0008 /* 0.33 CVRSRC with CVRSRC/24 step size, 0.50 CVRSRC with CVRSRC/32 step size */
#define CMP_0p37CVrsrc_OR_0p53CVrsrc     0x0009 /* 0.37 CVRSRC with CVRSRC/24 step size, 0.53 CVRSRC with CVRSRC/32 step size */
#define CMP_0p41CVrsrc_OR_0p56CVrsrc     0x000A /* 0.41 CVRSRC with CVRSRC/24 step size, 0.56 CVRSRC with CVRSRC/32 step size */
#define CMP_0p45CVrsrc_OR_0p59CVrsrc     0x000B /* 0.45 CVRSRC with CVRSRC/24 step size, 0.59 CVRSRC with CVRSRC/32 step size */
#define CMP_0p50CVrsrc_OR_0p62CVrsrc     0x000C /* 0.50 CVRSRC with CVRSRC/24 step size, 0.62CVRSRC with CVRSRC/32 step size */
#define CMP_0p54CVrsrc_OR_0p65CVrsrc     0x000D /* 0.54 CVRSRC with CVRSRC/24 step size, 0.65 CVRSRC with CVRSRC/32 step size */
#define CMP_0p58CVrsrc_OR_0p68CVrsrc     0x000E /* 0.58 CVRSRC with CVRSRC/24 step size, 0.68 CVRSRC with CVRSRC/32 step size */
#define CMP_0p62CVrsrc_OR_0p71CVrsrc     0x000F /* 0.62 CVRSRC with CVRSRC/24 step size, 0.71 CVRSRC with CVRSRC/32 step size */
#define CMP_VRef_SELECT_MASK             (~CMP_0p62CVrsrc_OR_0p71CVrsrc)

/******************************************************************************
 Macro      : mCMP2_EnblDsbl(state)
 Overview   : Macro Enables/Disables the Comparator 2
 Parameter  : state - *1 Comparator is enabled 
                      *0 Comparator is disabled
 Remarks    : None
 *****************************************************************************/
#define mCMP2_EnblDsbl(state)      		(CMCONbits.C2EN = state)

/******************************************************************************
 Macro      : mCMP1_EnblDsbl(state)
 Overview   : Macro Enables/Disables the Comparator 1
 Parameter  : state -  *1 Comparator is enabled 
                       *0 Comparator is disabled
 Remarks    : None
 *****************************************************************************/
#define mCMP1_EnblDsbl(state)      		(CMCONbits.C1EN = state)

/******************************************************************************
 Macro       : mCMP2_Output_EnblDsbl(state) 
 Overview    : Macro Enables/Disables Comparator 2 output on the output pad 
 Parameter   : state -  *1 Comparator output driven on the output pad 
                        *0 Comparator output is not driven on the output pad
 Remarks     : None
*****************************************************************************/
#define mCMP2_Output_EnblDsbl(state)    (CMCONbits.C2OUTEN = state)

/******************************************************************************
 Macro       : mCMP1_Output_EnblDsbl(state) 
 Overview    : Macro Enables/Disables Comparator 1 output on the output pad 
 Parameter   : state - *1 Comparator output driven on the output pad 
                       *0 Comparator output is not driven on the output pad
 Remarks     : None
 *****************************************************************************/
#define mCMP1_Output_EnblDsbl(state)    (CMCONbits.C1OUTEN = state)

/******************************************************************************
 Macro       : mCMP2_Get_STATE() 
 Overview    : Macro Returns state of Comparator output
              When  C2INV = 0:
               1 = C2 VIN+ > C2 VIN-
               0 = C2 VIN+ < C2 VIN
              When   C2INV = 1:
               0 = C2 VIN+ > C2 VIN-
               1 = C2 VIN+ < C2 VIN- 
 Parameter   : None 
 Remarks     : State of Comparator depends on Inverse selection  bit in 
              control register
 *****************************************************************************/
#define mCMP2_Get_STATE()      			(CMCONbits.C2OUT)

/******************************************************************************
 Macro       : mCMP1_Get_STATE() 
 Overview    : Macro Returns state of Comparator output
              When  C2INV = 0:
               1 = C2 VIN+ > C2 VIN-
               0 = C2 VIN+ < C2 VIN
              When   C2INV = 1:
               0 = C2 VIN+ > C2 VIN-
               1 = C2 VIN+ < C2 VIN- 
 Parameter   : None 
 Remarks     : State of Comparator depends on Inverse selection  bit in
              control register            
 ****************************************************************************/
#define mCMP1_Get_STATE()      			(CMCONbits.C1OUT)

/***********************************************************************
Macro      : EnableIntCMP
Overview   : This macro enables the comparator interrupt. 
Parameter  : None 
Remarks    : This macro sets comparator Interrupt Enable bit of Interrupt 
             Enable Control Register.
************************************************************************/ 
#define EnableIntCMP               (IEC1bits.CMIE = 1)

/***********************************************************************
Macro      : DisableIntCMP
Overview   : This macro disables the comparator interrupt.
Parameter  : None
Remarks    : This macro clears comparator Interrupt Enable bit of Interrupt 
             Enable Control register.
************************************************************************/ 
#define DisableIntCMP                (IEC1bits.CMIE = 0)

/***********************************************************************
Macro      : SetPriorityIntCMP (priority)
Overview   : This macro sets priority for comparator interrupt. 
Parameter  : priority - This input parameter is the level of interrupt priority 
Remarks    : This macro sets comparator Interrupt Priority bits of Interrupt 
             Priority Control register.
************************************************************************/  
#define SetPriorityIntCMP(priority)     (IPC4bits.CMIP = priority)

/*******************************************************************
Macro       : CMP_Clear_Intr_Status_Bit
Overview    : Macro to Clear Comparator Interrupt Status bit 
Parameter   : None 
Remarks     : None 
*******************************************************************/
#define CMP_Clear_Intr_Status_Bit     (IFS1bits.CMIF = 0)


extern void Config_CMP(unsigned short int config1 , unsigned short int config2);

#else 
/*Registers Defaults*/
#define COMP_CM1CON_VAL    				 0x0000
#define COMP_CM2CON_VAL    				 0x0000
#define COMP_CM3CON_VAL    				 0x0000

/**** CMxCON register definition ****/
#define CMP_ENABLE                  	 0x8000 /* Comparator is enabled */
#define CMP_DISABLE                      0x0000 /* Comparator is disabled */
#define CMP_ENBL_DSBL_MASK               (~CMP_ENABLE)

#define CMP_OUTPUT_ENABLE                0x4000 /* Comparator output present on the CXOUT pin */
#define CMP_OUTPUT_DISABLE               0x0000 /* Comparator output is internal only */
#define CMP_OUTPUT_MASK                  (~CMP_OUTPUT_ENABLE)

#define CMP_OUTPUT_INVERT    	         0x2000 /* Comparator output inverted */
#define CMP_OUTPUT_NOT_INVERT            0x0000 /* Comparator output not inverted */
#define CMP_OUTPUT_INVERT_MASK           (~CMP_OUTPUT_INVERT)

#if defined (cmp_v2_4)
#define CMP_ENABLE_IN_LOW_POWER    	     0x1000 /* Comparator OPERATES IN lOW POWER MODE */
#define CMP_DISABLE_IN_LOW_POWER   	     0x0000 /* Comparator OPERATES IN lOW POWER MODE */
#define CMP_ENABLE_IN_LOW_MASK           (~CMP_ENABLE_IN_LOW_POWER) 
#endif

#define CMP_CHANGE_STATE                 0x0200 /* Comparator output changed states */
#define CMP_NO_CHANGE                    0x0000 /* Comparator output did not change states */
#define CMP_STATE_MASK                   (~CMP_CHANGE_STATE )

#define CMP_INTERRUPT_ON_ANY_EDGE		 0X00C0 /* Interrupt generated on any edge of the selected comparator output*/
#define CMP_INTERRUPT_ON_FALLING_EDGE	 0X0080 /* Interrupt generated only on falling edge of the selected comparator output*/
#define CMP_INTERRUPT_ON_RISING_EDGE	 0X0040 /* Interrupt generated only on rising edge of the selected comparator output*/
#define CMP_INTERRUPT_DISABLED			 0X0000  /* Interrupt generation is disabled */
#define CMP_INTERRUP_EDGE_MASK           (~CMP_INTERRUPT_ON_ANY_EDGE) 

#define CMP_POS_IP_CV_Ref                0x0010 /* Non_inverting input connects to internal CVref voltage */ 
#define CMP_POS_IP_CXINA 	             0x0000 /* Non_inverting input is connected to CXINA pin */
#define CMP_POS_IP_MASK                  (~CMP_POS_IP_CV_Ref)

#define CMP_NEG_IP_CXINB				 0X0000 /* Input is connected to CXINB pin */

#if defined (cmp_v2_1) || defined (cmp_v2_2) || defined (cmp_v2_3)||defined (cmp_v2_5) 
#define CMP_NEG_IP_CXINC			     0X0001 /* Input is connected to CXINC pin */
#define CMP_NEG_IP_CXIND			     0X0002 /* Input is connected to CXIND pin */
#endif

#if defined (cmp_v2_3)
#define CMP_NEG_IP_CV_Ref			     0X0003 /* Input is connected to CVRef */
#elif defined (cmp_v2_5)
#define CMP_NEG_IP_REFVOLT_BGREF_SOURCE  0X0003 /* Input is connected to reference voltage specified by bits BGSEL */
#else
#define CMP_NEG_IP_VBG_DIV_2		     0X0003 /* Input is connected to VBGdiv2 */
#endif

#define CMP_NEG_IP_MASK                  (~CMP_NEG_IP_VBG_DIV_2)

/**** CVRCON register definition ****/
#if defined (cmp_v2_3)
#define CMP_VRefP_POS_SEL_IN_PIN   0x0400 /* CVREF input pin as CVREF+ reference output to comparators */
#define CMP_VRefP_POS_SEL_MODLUE   0x0000 /* Voltage Reference modules generated output as CVREF+ reference output to COMPARATOR */
#define CMP_VRef_POS_SEL_MASK       (~CMP_VRefP_POS_SEL_IN_PIN)

#define CMP_VRefP_NEG_SEL_MODULE   0x0300 /* Voltage Reference modules generated output as CVREF- reference output to COMPARATOR */
#define CMP_VRefP_NEG_SEL_VBG_DIV_6  0x0200 /* VBG/6 as as CVREF- reference output to comparators */
#define CMP_VRefP_NEG_SEL_VBG	     0x0100 /* VBG as as CVREF- reference output to comparators */
#define CMP_VRefP_NEG_SEL_VBG_DIV_2  0x0000 /*VBG/2 as as CVREF- reference output to comparators */
#define CMP_VRefP_NEG_SEL_MASK           (~CMP_VRefP_NEG_SEL_MODULE) 
#endif

#if defined (cmp_v2_5)
#define CMP_VRef_DAC_EXT_MODULE          0x0400 /* A peripheral(DAC) external to this module provides the reference voltage*/
#define CMP_VRef_CVR_INT_MODULE          0x0000 /* CVR (4-bit DAC) within this module provides the reference voltage */
#define CMP_VRef_MODULE_MASK                    (~CMP_VRef_DAC_EXT_MODULE) 

#define CMP_BGREF_SOURCE_VOLT3           0x0300 /*Bandgap/reference source voltage 3 */
#define CMP_BGREF_SOURCE_VOLT2           0x0200 /*Bandgap/reference source voltage 2*/
#define CMP_BGREF_SOURCE_VOLT1	         0x0100 /*Bandgap/reference source voltage 1*/
#define CMP_BGREF_SOURCE_VOLT0           0x0000 /*Bandgap/reference source voltage 0 */
#define CMP_BGREF_SOURCE_MASK            (~CMP_BGREF_SOURCE_VOLT3)
#endif

#define CMP_VRef_Enable                  0x0080 /* CVREF circuit powered on */
#define CMP_VRef_Disable                 0x0000 /* CVREF circuit powered down */
#define CMP_VRef_MASK                   (~CMP_VRef_Enable)

#define CMP_VRef_OUTPUT_Enable           0x0040 /* CVREF voltage level is output on CVREF pin */
#define CMP_VRef_OUTPUT_Disable          0x0000 /* CVREF voltage level is disconnected from CVREF pin */
#define CMP_VRef_OUTPUT_MASK             (~CMP_VRef_OUTPUT_Enable)

#define CMP_VRef_SELECT_24_STEPS   	 	 0x0020 /* 0 to 0.67 CVRSRC, with CVRSRC/24 step size */
#define CMP_VRef_SELECT_32_STEPS         0x0000 /* 0.25 CVRSRC to 0.75 CVRSRC, with CVRSRC/32 step size */
#define CMP_VRef_STEP_SELECT_MASK        (~CMP_VRef_SELECT_24_STEPS)

#define CMP_Vrsrc_Vref_Vref        		 0x0010 /* Comparator reference source CVRSRC = VREF+  VREF- */
#define CMP_Vrsrc_AVDD_AVSS        		 0x0000 /* Comparator reference source CVRSRC = AVDD  AVSS */
#define CMP_Vrsrc_MASK                   (~CMP_Vrsrc_Vref_Vref)

#define CMP_0p0CVrsrc_OR_0p25CVrsrc      0x0000 /* 0 CVRSRC with CVRSRC/24 step size, 0.25 CVRSRC with CVRSRC/32 step size */
#define CMP_0p04CVrsrc_OR_0p28CVrsrc     0x0001 /* 0.40 CVRSRC with CVRSRC/24 step size, 0.28 CVRSRC with CVRSRC/32 step size */
#define CMP_0p08CVrsrc_OR_0p31CVrsrc     0x0002 /* 0.80 CVRSRC with CVRSRC/24 step size, 0.31 CVRSRC with CVRSRC/32 step size */
#define CMP_0p12CVrsrc_OR_0p34CVrsrc     0x0003 /* 0.12 CVRSRC with CVRSRC/24 step size, 0.34 CVRSRC with CVRSRC/32 step size */
#define CMP_0p16CVrsrc_OR_0p37CVrsrc     0x0004 /* 0.16 CVRSRC with CVRSRC/24 step size, 0.37 CVRSRC with CVRSRC/32 step size */
#define CMP_0p20CVrsrc_OR_0p40CVrsrc     0x0005 /* 0.20 CVRSRC with CVRSRC/24 step size, 0.40 CVRSRC with CVRSRC/32 step size */
#define CMP_0p25CVrsrc_OR_0p43CVrsrc     0x0006 /* 0.25 CVRSRC with CVRSRC/24 step size, 0.43 CVRSRC with CVRSRC/32 step size */
#define CMP_0p29CVrsrc_OR_0p46CVrsrc     0x0007 /* 0.29 CVRSRC with CVRSRC/24 step size, 0.46 CVRSRC with CVRSRC/32 step size */
#define CMP_0p33CVrsrc_OR_0p50CVrsrc     0x0008 /* 0.33 CVRSRC with CVRSRC/24 step size, 0.50 CVRSRC with CVRSRC/32 step size */
#define CMP_0p37CVrsrc_OR_0p53CVrsrc     0x0009 /* 0.37 CVRSRC with CVRSRC/24 step size, 0.53 CVRSRC with CVRSRC/32 step size */
#define CMP_0p41CVrsrc_OR_0p56CVrsrc     0x000A /* 0.41 CVRSRC with CVRSRC/24 step size, 0.56 CVRSRC with CVRSRC/32 step size */
#define CMP_0p45CVrsrc_OR_0p59CVrsrc     0x000B /* 0.45 CVRSRC with CVRSRC/24 step size, 0.59 CVRSRC with CVRSRC/32 step size */
#define CMP_0p50CVrsrc_OR_0p62CVrsrc     0x000C /* 0.50 CVRSRC with CVRSRC/24 step size, 0.62CVRSRC with CVRSRC/32 step size */
#define CMP_0p54CVrsrc_OR_0p65CVrsrc     0x000D /* 0.54 CVRSRC with CVRSRC/24 step size, 0.65 CVRSRC with CVRSRC/32 step size */
#define CMP_0p58CVrsrc_OR_0p68CVrsrc     0x000E /* 0.58 CVRSRC with CVRSRC/24 step size, 0.68 CVRSRC with CVRSRC/32 step size */
#define CMP_0p62CVrsrc_OR_0p71CVrsrc     0x000F /* 0.62 CVRSRC with CVRSRC/24 step size, 0.71 CVRSRC with CVRSRC/32 step size */
#define CMP_VRef_SELECT_MASK             (~CMP_0p62CVrsrc_OR_0p71CVrsrc)

#if defined (cmp_v2_2) || defined (cmp_v2_3) ||defined (cmp_v2_5)|| defined (LIB_BUILD)
/*****************************************************************************
 Macro      : mCMP3_EnblDsbl(state)
 Overview   : Macro Enables/Disables the Comparator 3
 Parameter  : state - *1 Comparator is enabled 
                      *0 Comparator is disabled
 Remarks    : None
*****************************************************************************/
#define mCMP3_EnblDsbl(state)           (CM3CONbits.CEN = state)

/******************************************************************************
 Macro       : mCMP3_Output_EnblDsbl(state) 
 Overview    : Macro Enables/Disables Comparator 3 output on the output pad 
 Parameter   : state - *1 Comparator output driven on the output pad 
                       *0 Comparator output is not driven on the output pad
 Remarks     : None
*****************************************************************************/
#define mCMP3_Output_EnblDsbl(state)    (CM3CONbits.COE = state)

/******************************************************************************
 Macro       : mCMP3_Get_STATE() 
 Overview    : Macro Returns state of Comparator output
               When  C3INV = 0:
               1 = C3 VIN+ > C3 VIN-
               0 = C3 VIN+ < C3 VIN
               When   C3INV = 1:
               0 = C3 VIN+ > C3 VIN-
               1 = C3 VIN+ < C3 VIN- 
 Parameter   : None 
 Remarks     : State of Comparator depends on Inverse selection  bit in 
               control register
******************************************************************************/
#define mCMP3_Get_STATE()                (CM3CONbits.COUT)

/******************************************************************************
 Macro       : mCMP3_Clear_Event
 Overview    : Macro clears the comparator event bit.
 Parameter   : None
 Remarks     : Clear this event bit to generate subsequent trigger and interrupt.
*****************************************************************************/
#define mCMP3_Clear_Event             (CM3CONbits.CEVT = 0)

extern void Config_CMP3(unsigned short int config1 , unsigned short int config2);

#endif

#if defined (cmp_v2_1) || defined (cmp_v2_4)
/******************************************************************************
 Macro      : mCMP2_EnblDsbl(state)
 Overview   : Macro Enables/Disables the Comparator 2
 Parameter  : state - *1 Comparator is enabled 
                      *0 Comparator is disabled
 Remarks    : None
*****************************************************************************/
#define mCMP2_EnblDsbl(state)           (CM2CONbits.CON = state)

/******************************************************************************
 Macro      : mCMP1_EnblDsbl(state)
 Overview   : Macro Enables/Disables the Comparator 1
 Parameter  : state - *1 Comparator is enabled 
                      *0 Comparator is disabled
 Remarks    : None
*****************************************************************************/
#define mCMP1_EnblDsbl(state)           (CM1CONbits.CON = state)

#else
/******************************************************************************
 Macro      : mCMP2_EnblDsbl(state)
 Overview   : Macro Enables/Disables the Comparator 2
 Parameter  : state - *1 Comparator is enabled 
                      *0 Comparator is disabled
 Remarks    : None
*****************************************************************************/
#define mCMP2_EnblDsbl(state)           (CM2CONbits.CEN = state)

/******************************************************************************
 Macro      : mCMP1_EnblDsbl(state)
 Overview   : Macro Enables/Disables the Comparator 1
 Parameter  : state - *1 Comparator is enabled 
                      *0 Comparator is disabled
 Remarks    : None
*****************************************************************************/
#define mCMP1_EnblDsbl(state)           (CM1CONbits.CEN = state)
#endif

/******************************************************************************
Macro       : mCMP2_Output_EnblDsbl(state) 
Overview    : Macro Enables/Disables Comparator 2 output on the output pad 
Parameter   : state - *1 Comparator output driven on the output pad 
                      *0 Comparator output is not driven on the output pad
Remarks     : None
*****************************************************************************/
#define mCMP2_Output_EnblDsbl(state)    (CM2CONbits.COE = state)

/******************************************************************************
 Macro       : mCMP1_Output_EnblDsbl(state) 
 Overview    : Macro Enables/Disables Comparator 1 output on the output pad 
 Parameter   : state - *1 Comparator output driven on the output pad 
                       *0 Comparator output is not driven on the output pad
 Remarks     : None
*****************************************************************************/
#define mCMP1_Output_EnblDsbl(state)    (CM1CONbits.COE = state)

/******************************************************************************
 Macro       : mCMP2_Get_STATE() 
 Overview    : Macro Returns state of Comparator output
              When  C2INV = 0:
               1 = C2 VIN+ > C2 VIN-
               0 = C2 VIN+ < C2 VIN
              When   C2INV = 1:
               0 = C2 VIN+ > C2 VIN-
               1 = C2 VIN+ < C2 VIN- 
 Parameter   : None 
 Remarks     : State of Comparator depends on Inverse selection  bit in 
              control register
******************************************************************************/
#define mCMP2_Get_STATE()                 (CM2CONbits.COUT)

/******************************************************************************
 Macro       : mCMP1_Get_STATE() 
 Overview    : Macro Returns state of Comparator output
              When  C1INV = 0:
               1 = C1 VIN+ > C1 VIN-
               0 = C1 VIN+ < C1 VIN
              When   C1INV = 1:
               0 = C1 VIN+ > C1 VIN-
               1 = C1 VIN+ < C1 VIN- 
 Parameter   : None 
 Remarks     : State of Comparator depends on Inverse selection  bit in 
              control register
******************************************************************************/
#define mCMP1_Get_STATE()                  (CM1CONbits.COUT)

/******************************************************************************
 Macro       : mCMP2_Clear_Event
 Overview    : Macro clears the comparator event bit.
 Parameter   : None
 Remarks     : Clear this event bit to generate subsequent trigger and interrupt.
*****************************************************************************/
#define mCMP2_Clear_Event             (CM2CONbits.CEVT = 0)

/******************************************************************************
 Macro       : mCMP1_Clear_Event 
 Overview    : Macro clears the comparator event bit.
 Parameter   : None
 Remarks     : Clear this event bit to generate subsequent trigger and interrupt.
*****************************************************************************/
#define mCMP1_Clear_Event             (CM1CONbits.CEVT = 0)

/***********************************************************************
Macro      : EnableIntCMP
Overview   : This macro enables the comparator interrupt. 
Parameter  : None 
Remarks    : This macro sets comparator Interrupt Enable bit of Interrupt 
             Enable Control Register.
************************************************************************/ 
#define EnableIntCMP                (IEC1bits.CMIE = 1)

/***********************************************************************
Macro      : DisableIntCMP
Overview   : This macro disables the comparator interrupt.
Parameter  : None
Remarks    : This macro clears comparator Interrupt Enable bit of Interrupt 
             Enable Control register.
************************************************************************/ 
#define DisableIntCMP                (IEC1bits.CMIE =0)

/***********************************************************************
Macro      : SetPriorityIntCMP(priority) 
Overview   : This macro sets priority for comparator interrupt. 
Parameter  : priority - This input parameter is the level of interrupt priority
Remarks    : This macro sets comparator Interrupt Priority bits of Interrupt 
             Priority Control register.
************************************************************************/  
#define SetPriorityIntCMP(priority)     (IPC4bits.CMIP = priority)

/*******************************************************************
Macro       : CMP_Clear_Intr_Status_Bit
Overview    : Macro to Clear Comparator Interrupt Status bit 
Parameter   : None 
Remarks     : None 
*******************************************************************/
#define CMP_Clear_Intr_Status_Bit     (IFS1bits.CMIF = 0)

extern void Config_CMP1(unsigned short int config1 , unsigned short int config2);

extern void Config_CMP2(unsigned short int config1 , unsigned short int config2);

#endif

#else		//This preprocessor conditional statement is to avoid unintended linking for unsuppported devices.
#warning "Does not build on this target"
#endif

#endif  /* __COMPARATOR_H */
