#if defined(__PIC24F__)
#include "p24Fxxxx.h"
#endif
#include "PwrMgnt.h"

#if defined (pwrmgnt_v2_1) || defined (LIB_BUILD)

extern int __attribute__((space(prog))) _FOSCSEL;
 /******************************************************************************
 * Function:        BOOL PwrMgnt_OscSel_v2(UINT16 new_oscsel)
 *
 * PreCondition:    None   
 *
 * Side Effects:    None
 *
 * Overview:        For seamless migration, it is recommended to call the above function as "PwrMgnt_OscSel".
 *                 This function should be used to select the appropriate oscillator.
 *
 * Input:           new_oscsel - This parameter is the value of the new 
 *                                      oscillator to be selected.
 *                  
 * Returns:          BOOL - TRUE : If successfully changed new  oscillator select 
 *                                bits.
 *                         FALSE: If 'FCKSM1 = 1' or new oscillator value is same 
 *                                as old oscillator value or PLL is not locked.
 *
 * Note:            None
 *****************************************************************************/
BOOL PwrMgnt_OscSel_v2(UINT16 new_oscsel)
{
   UINT16 LocalConfigword = 0;
   UINT16 delay = 0;
   UINT16 addr;
   UINT8  CPU_IPL;
   UINT8  tempOSCCONL;
/* Disable Global Interrupt */
   SET_AND_SAVE_CPU_IPL(CPU_IPL,7);

  TBLPAG =  __builtin_tblpage(&_FOSCSEL);
  addr = __builtin_tbloffset(&_FOSCSEL);
  asm( "tblrdl.w  [%1] , %0" : "=r"(LocalConfigword) : "r"(addr));

   if((LocalConfigword & 0x0080) || (new_oscsel == OSCCONbits.COSC))
   {
      RESTORE_CPU_IPL(CPU_IPL);
      return(FALSE);
   }
   tempOSCCONL = (OSCCON & 0xFF);
   tempOSCCONL |= 0x1;

   __builtin_write_OSCCONH(new_oscsel);
   __builtin_write_OSCCONL(tempOSCCONL);

   while((0 != OSCCONbits.OSWEN)&&(200 > delay))  /* appropriate delay need to be calculated */
   {
    delay++;
   }
   
   if(0 != OSCCONbits.OSWEN)
   {
      RESTORE_CPU_IPL(CPU_IPL);
      return(FALSE);
   }
/* Enable Global Interrupt */
      RESTORE_CPU_IPL(CPU_IPL);

   return(TRUE);
}

#else
#warning "Does not build on this target"
#endif
