 
#include <outcompare.h>

#if defined (ocmp_v2_1) ||defined (ocmp_v2_2)|| defined (LIB_BUILD)
/************************************************************************************************
Function Prototype : void OpenOC78_GB(unsigned int config1,unsigned int config2, 
                                      unsigned long int value1, unsigned long int value2)

Include            : outcompare.h
 
Description        : For seamless migration, it is recommended to call the above function as "OpenOC78".
 
Arguments          : config1 - This contains the parameters to be configured in the OCxCON1 register 				
					 config2 - This contains the parameters to be configured in the OCxCON2 register 
					 value1 - This contains the value to be stored into OCxRS Secondary					
			                  Register.[In single compare mode, user may set this parameter as 0x0000]					
			 		 value2 - This contains the value to be stored into OCxR Main Register
 
Return Value       : None
 
Remarks            : This function configures the Output Compare Module Control register
                     (OCxCON)with the parameters like Clock select, mode of operation, 
                      operation in Idle mode.It also configures the OCxRS and OCxR registers.
**********************************************************************************************/

void OpenOC78_GB(unsigned int config1,unsigned int config2, unsigned long int value1, unsigned long int value2)
{
    OC7CON1bits.OCM = 0; /* turn off OC before switching to new mode */
    OC8CON1bits.OCM = 0;
    
    OC7RS = value1;     /* assign value1 to OCxRS Secondary Register */
    OC8RS = value1>>16;
    OC7R = value2;      /* assign value2 to OCxR Main Register*/  
    OC8R = value2>>16;   
    
    OC7CON1 = config1;    /* assign config to OCxCON Register*/
    OC8CON2 = config1;    
    OC7CON2 = config2;
    OC8CON2 = config2;
    
    OC7CON2bits.OC32 = 1; /*cascade mode is enabled*/
    OC8CON2bits.OC32 = 1;
    
    OC7CON2bits.OCTRIS = 1; // Output compare 1 not generate pulses.
}

#else
#warning "Does not build on this target"
#endif
