 
#include <outcompare.h>

#if defined (ocmp_v1_2) || defined (LIB_BUILD)
/**************************************************************************************
Function Prototype : char SetPulseOC2(unsigned int pulse_start,unsigned int pulse_stop)
 
Include            : outcompare.h
 
Description        : This function configures the Output Compare main and secondary
                     registers (OCxR and OCxRS ) when the module is not in PWM mode.
 
Arguments          : pulse_start - This is the value to be stored into Output Compare 
                     Main register (OCxR).
                     pulse_stop - This is the value to be stored into Output Compare 
                     Secondary register (OCxRS). 
                    [For Single Compare Mode pulse_stop value is ignored.]
 
Return Value       : Returns '1' if value is loaded.Else -1 is returned.
 
Remarks            : The Output Compare duty cycle registers (OCxR and OCxRS) will be
                     configured with new values only if the module is not in PWM mode.
**************************************************************************************/

char SetPulseOC2(unsigned int pulse_start, unsigned int pulse_stop)
{   
   
    if((OC2CONbits.OCM & 0x06) != 0x06) /* check if OC is in NON PWM Mode */
    {
	     if(((OC2CONbits.OCM & 0x07) >> 2)==0x01) /* check if OC is in Dual Compare Mode */
	     {
	        OC2R = pulse_start; /* assign pulse_start to Main Register */
	        OC2RS = pulse_stop; /* assign pulse_stop to Secondary Register */
	     }
	     else
	       OC2R = pulse_start;
	       
       return 1;
    }     
    else    
       return -1;   
       
}

#else
#warning "Does not build on this target"
#endif
