 
#include "spi.h"

#if defined (spi_v1_3) || defined (LIB_BUILD)
/********************************************************************************
Function           : void WriteSPI3(unsigned int data_out)

Description        : This function writes the data to be transmitted 
                     into the Transmit Buffer (SPIxBUF) register.
 
Arguments          : data_out - This is the data to be transmitted which 
                     will be stored in SPI buffer.
 
Returns            : None
 
Remarks            : This function writes the data (byte/word) to be transmitted
                     into the transmit buffer.
                     If 16-bit communication is enabled, the 16-bit value is 
                     written to the transmit buffer.
                     If 8-bit communication is enabled, then upper byte is masked
                     and then written to the transmit buffer.
**********************************************************************************/
void WriteSPI3(unsigned int data_out)
{
    if (SPI3CON1bits.MODE16)           /* word write */
        SPI3BUF = data_out;
    else
        SPI3BUF = data_out & 0xff;	  /*  byte write  */
}
#else
#warning "Does not build on this target"
#endif
