 
#include "spi.h"

#if defined (spi_v1_1) || defined (spi_v1_2) || defined (spi_v1_3) || defined (LIB_BUILD)
/*************************************************************************************
Function           : unsigned int getsSPI1(unsigned int length,unsigned int *rdptr,unsigned int spi_data_wait);

Description        : This function reads a string of data of specified length and 
                     stores it into the location specified
 
Arguments          : length - This is the length of the string to be received.
                     rdptr - This is the pointer to the location where the data
                     received have to be stored.
                     spi_data_wait - This is the time-out count for which the module
                     has to wait before return. If the time-out count is N, the 
                     actual time out would be about (19 * N  1) instruction cycles.
 
Returns            : This function returns the number of bytes yet to be received.
                     If the return value is a 0, it indicates that the complete 
                     string has been received. 
                     If the return value is a non-zero, it indicates that the 
                     complete string has not been received
 
Remarks            : None                  
***************************************************************************************/
unsigned int getsSPI1(unsigned int length, unsigned int *rdptr, unsigned int spi_data_wait)
{
    int wait = 0;
    char *temp_ptr = (char *)rdptr;
    while (length)                     /* stay in loop until length = 0  */
    {
        while(!DataRdySPI1())
        {

           if(wait < spi_data_wait)
               wait++ ;                /* wait for time out operation */
           else
               return(length);         /*Time out, return number of byte/word to be read */
        }
        wait = 0;
        
        if(SPI1CON1bits.MODE16)
            *rdptr++ = getcSPI1();     /* read a single word */
        else
            *temp_ptr++ = getcSPI1();  /* read a single byte */
        length--;                      /* reduce string length count by 1*/
    }
    return (length);                   /* return number of byte/word to be read i.e, 0 */
}

#else
#warning "Does not build on this target"
#endif
