 
#include "spi.h"

#if defined (spi_v1_3) || defined (LIB_BUILD)
/******************************************************************************************
Function           : void putsSPI3(unsigned int length,unsigned int *wrptr)

Description        : This function writes the data to be transmitted into the
                     Transmit Buffer (SPIxBUF) register.
 
Arguments          : length - This is the number of data words/bytes to be transmitted.
                     wrptr - This is the pointer to the string of data to be transmitted
 
Returns            : None
 
Remarks            : This function writes the specified length of data words/bytes to be
                     transmitted into the transmit buffer.Once the transmit buffer is full,
                     it waits until the data gets transmitted and then writes the next data
                     into the Transmit register.The control remains in this function if SPI
                     module is disabled while SPITBF bit is set.
********************************************************************************************/
void putsSPI3(unsigned int length, unsigned int *wrptr)
{
    char *temp_ptr = (char *) wrptr;
    while (length)                   /* write byte/word until length is 0 */
    {
        if(SPI3CON1bits.MODE16)
            SPI3BUF = *wrptr++;      /* initiate SPI bus cycle by word write */
        else
            SPI3BUF = *temp_ptr++;   /* initiate SPI bus cycle by byte write */
        while(SPI3STATbits.SPITBF);  /* wait until 'SPITBF' bit is cleared */
        length--;                    /* decrement length */
    }
}

#else
#warning "Does not build on this target"
#endif
