#include "spi.h"
#include "sram.h"

#if defined (sram_v1_1) || defined (LIB_BUILD)
/******************************************************************************
 Function:        	void SRAMCommand(unsigned char AddLB, unsigned char AddHB, unsigned char RWCmd)
 
Overview:        	This function issues various command to access SRAM

 Input:           	AddLB - LSB of Address of SRAM
                      AddHB - MSB of Address of SRAM 
						RWCmd - Type of operation
								*	SRAM_RD_CMD  		
								*	SRAM_WR_CMD  			
								*	SRAM_STATUS_RD_CMD   	
								*	SRAM_STATUS_WR_CMD 
								*	SRAM_BYTE_MODE			
								*	SRAM_PAGE_MODE			
								*	SRAM_SEQ_MODE    		
					
 Returns:      None


Remarks:       None
 *****************************************************************************/
void SRAMCommand(unsigned char AddLB, unsigned char AddHB, unsigned char RWCmd)
{
	unsigned char ReadData;
	WriteSPI(RWCmd);	//Send Read or Write command to SRAM
	while(!SPI_Rx_Buf_Full);
	ReadData =ReadSPI();	
	WriteSPI(AddHB);//Send High byte of address to SRAM
	while(!SPI_Rx_Buf_Full);
	ReadData =ReadSPI();	
	WriteSPI(AddLB);//Send Low byte of address to SRAM
	while(!SPI_Rx_Buf_Full);
	ReadData =ReadSPI();
}

#else
#warning "Does not build on this target"
#endif
