#include "spi.h"
#include "sram.h"

#if defined (sram_v1_1) || defined (LIB_BUILD)
/******************************************************************************
 Function:        	unsigned char SRAMReadByte(unsigned char AddLB,unsigned char AddHB)
 
 Overview:        	This function reads a byte from SRAM

 Input:           	AddLB - LSB of Address of SRAM
                    AddHB - MSB of Address of SRAM

 Returns:          	Returns a byte read from SRAM

 Remarks:            	None
 *****************************************************************************/
unsigned char SRAMReadByte(unsigned char AddLB,unsigned char AddHB)
{
	unsigned char ReadData;
	SRAMWriteStatusReg(SRAM_BYTE_MODE);			//Ensure Byte mode is selected
	SRAM_CS = 0;								//Select SRAM	
	SRAMCommand(AddLB,AddHB,SRAM_RD_CMD);//Send Read command to SRAM along with address
	WriteSPI(SRAM_DUMMY_VAL);	//Send dummy data so SRAM can put desired Data read from SRAM
	while(!SPI_Rx_Buf_Full);
	ReadData =ReadSPI();
	SRAM_CS = 1;								//Deselect SRAM
	return(ReadData);							//Return read data from SRAM
}

#else
#warning "Does not build on this target"
#endif
