#include "spi.h"
#include "sram.h"

#if defined (sram_v1_1) || defined (LIB_BUILD)
/******************************************************************************
 Function:        	unsigned char SRAMReadPage(unsigned char AddLB,unsigned char AddHB,unsigned char *ReadData)
 
 Overview:        	This function reads a page(32Bytes) from SRAM

 Input:           	AddLB - LSB of Address of SRAM
                        AddHB - MSB of Address of SRAM 
						*ReadData - Pointer to the buffer where data read from SRAM is stored
						
Returns:          	Returns number of bytes read from SRAM

Remarks:            	None
 *****************************************************************************/
unsigned char SRAMReadPage(unsigned char AddLB,unsigned char AddHB,unsigned char *ReadData)
{
	unsigned char ReadCnt;
	SRAMWriteStatusReg(SRAM_PAGE_MODE);
	//Send Read command to SRAM along with address
	SRAM_CS = 0;
	SRAMCommand(AddLB,AddHB,SRAM_RD_CMD);
	//Send dummy data so SRAM can put desired Data read from SRAM
	for(ReadCnt = 0; ReadCnt < SRAM_PAGE_SIZE; ReadCnt++)
	{
		WriteSPI(SRAM_DUMMY_VAL);
		while(!SPI_Rx_Buf_Full);
		*ReadData++ = ReadSPI();
	}
	SRAM_CS = 1;
	return(ReadCnt);			//Return no# of bytes read from SRAM
}

#else
#warning "Does not build on this target"
#endif
