#include "spi.h"
#include "sram.h"

#if defined (sram_v1_1) || defined (LIB_BUILD)
/******************************************************************************
 Function:     void SRAMReadSeq(unsigned char AddLB,unsigned char AddHB,
                                              unsigned char *ReadData,unsigned int ReadCnt)
											  
 Overview:      This function writes 'n' number of bytes to SRAM where 'n' = WriteCnt

 Input:         AddLB - LSB of Address of SRAM
                  AddHB - MSB of Address of SRAM
				  *ReadData - pointer to the buffer where data read from SRAM is stored
				  ReadCnt - Number of bytes to be read from SRAM.
				  
 Returns:        None

 Remarks:          This function is very useful when you want to read more than one byte
				   where page boundry is not to be considered
 *****************************************************************************/
void SRAMReadSeq(unsigned char AddLB,unsigned char AddHB,unsigned char *ReadData,unsigned int ReadCnt)
{
	SRAMWriteStatusReg(SRAM_SEQ_MODE);			//Ensure Sequential mode is selected in SRAM
	//Send Read command to SRAM along with address
	SRAM_CS = 0;								//Select SRAM
	SRAMCommand(AddLB,AddHB,SRAM_RD_CMD);		
	//Send dummy data so SRAM can put desired Data read from SRAM
	for(; ReadCnt > 0; ReadCnt--)
	{
		WriteSPI(SRAM_DUMMY_VAL);
		while(!SPI_Rx_Buf_Full);
		*ReadData++ =ReadSPI();
	}
	SRAM_CS = 1;								//Deselect SRAM
}

#else
#warning "Does not build on this target"
#endif
