#include "spi.h"
#include "sram.h"

#if defined (sram_v1_1) || defined (LIB_BUILD)
/******************************************************************************
 Function:        	unsigned char SRAMWritePage(unsigned char AddLB,unsigned char AddHB, unsigned char *WriteData)
 
 Overview:        	This function writes a page(32Bytes) to SRAM

 Input:           	AddLB - LSB of Address of SRAM
                        AddHB - MSB of Address of SRAM 
                        *WriteData - Pointer to the buffer from where data is taken and written to SRAM
						
 Returns:          	Returns number of bytes written to SRAM

Remarks:            	None
 *****************************************************************************/
unsigned char SRAMWritePage(unsigned char AddLB,unsigned char AddHB, unsigned char *WriteData)
{
	unsigned char ReadData,WriteCnt;
	SRAMWriteStatusReg(SRAM_PAGE_MODE);				//Ensure Page Mode of SRAM is selected
	SRAM_CS = 0;									//Select SRAM
	SRAMCommand(AddLB,AddHB,SRAM_WR_CMD);			//Send first address of SRAM with Write mode selected
	//Send Data to be written to SRAM
	for(WriteCnt = 0;WriteCnt < SRAM_PAGE_SIZE;WriteCnt++)
	{
		WriteSPI(*WriteData++);
		while(!SPI_Rx_Buf_Full);
		ReadData =ReadSPI();
	}
	SRAM_CS = 1;									//Deselect SRAM
	return(WriteCnt);								//Return no# of bytes written to SRAM
}

#else
#warning "Does not build on this target"
#endif
