#include "spi.h"
#include "sram.h"

#if defined (sram_v1_1) || defined (LIB_BUILD)
/******************************************************************************
 Function:        	void SRAMWriteSeq(unsigned char AddLB,unsigned char AddHB, 
                                                   unsigned char *WriteData,unsigned int WriteCnt)
												   
												   
 Overview:        This function writes 'n' number of bytes to SRAM where 'n' = WriteCnt

 Input:           AddLB - LSB of Address of SRAM
                    AddHB - MSB of Address of SRAM
					*WriteData - Pointer to the buffer from where data is taken and written to SRAM
					WriteCnt - Number of bytes to be written to SRAM.
					
 Returns:          None

 Remarks:            This function is very useful when you want to write more than one byte
					   where page boundry is not to be considered
 *****************************************************************************/
void SRAMWriteSeq(unsigned char AddLB,unsigned char AddHB, unsigned char *WriteData,unsigned int WriteCnt)
{
	unsigned char DummyRead;
	SRAMWriteStatusReg(SRAM_SEQ_MODE );		//Ensure Sequential mode is selected in SRAM
	//Send Write command to SRAM along with address
	SRAM_CS = 0;							//Select SRAM
	SRAMCommand(AddLB,AddHB,SRAM_WR_CMD);
	//Send Data to be written to SRAM
	for(;WriteCnt > 0;WriteCnt--)
	{
		WriteSPI(*WriteData++);
		while(!SPI_Rx_Buf_Full);
		DummyRead =ReadSPI();
	}
	SRAM_CS = 1;							//Deselect SRAM
}

#else
#warning "Does not build on this target"
#endif
