 
#include <timer.h>

/* These devices support Timers 4 and 5 */
#if defined (tmr_v1_2) || defined (LIB_BUILD)

/****************************************************************************
Function Prototype : void ConfigIntTimer45(unsigned int config)

Include            : timer.h
 
Description        : This function configures the 32-bit timer interrupt.
 
Arguments          : config - Timer interrupt priority and enable/disable 
                     information as defined below
					 
		Timer Interrupt Priority
		   *	T45_INT_PRIOR_7					
		   *	T45_INT_PRIOR_6					
		   *	T45_INT_PRIOR_5					
		   *	T45_INT_PRIOR_4					
		   *	T45_INT_PRIOR_3					
		   *	T45_INT_PRIOR_2					
		   *	T45_INT_PRIOR_1					
		   *	T45_INT_PRIOR_0
		  Timer Interrupt Enable\Disable 					
		   *	T45_INT_ON					
		   *	T45_INT_OFF
					 
Return Value      : None
 
Remarks           : This function clears the Interrupt Flag (TxIF) bit 
                    and then sets the interrupt priority and enables/disables 
                    the interrupt.
******************************************************************************/

void ConfigIntTimer45(unsigned int config)
{
    IFS1bits.T5IF = 0;                   /* clear IF bit */
    IPC7bits.T5IP = (config &0x0007);    /* assigning Interrupt Priority */
    IEC1bits.T5IE = (config &0x0008)>>3; /* Interrupt Enable /Disable */
}

#else
#warning "Does not build on this target"
#endif
