 
#include <timer.h>

#if defined (tmr_v1_1) || defined (tmr_v1_2) || defined (LIB_BUILD)
/*******************************************************************************
Function Prototype : void OpenTimer23(unsigned int config,unsigned int period)
 
Include            : timer.h
 
Description        : This function configures the 32-bit timer module.
 
Arguments          : config - This contains the parameters to be configured in
                     the T2CON register as defined below
					 
			Timer Module On/Off						
			   *	T23_ON						
			   *	T23_OFF						
			Timer Module Idle mode On/Off						
			   *	T23_IDLE_CON						
			   *	T23_IDLE_STOP						
			Timer Gate time accumulation enable						
			   *	T23_GATE_ON						
			   *	T23_GATE_OFF						
			Timer prescaler						
			   *	T23_PS_1_1						
			   *	T23_PS_1_8						
			   *	T23_PS_1_64						
			   *	T23_PS_1_256						
			Timer clock source						
			   *	T23_SOURCE_EXT						
			   *	T23_SOURCE_INT						
			   
		  period - This contains the period match value to be stored 
		  into the PR register 
 
Return Value      : None
 
Remarks           : This function configures the 32-bit Timer Control register and 
                    sets the period match value into the PR register. 
**********************************************************************************/

void OpenTimer23(unsigned int  config,unsigned long int period)
{
    TMR2 = 0;               /* Reset Timer2 to 0x0000 */
    TMR3 = 0;               /* Reset Timer3 to 0x0000 */
    PR2 = period;           /* assigning Period to PR2 */
    PR3 = period>>16;       /* Period to  PR3 Register */
    T2CON =  config;        /* Configure timer control reg */
    T2CONbits.T32 = 1;
}

#else
#warning "Does not build on this target"
#endif
