 
#include <timer.h>

/* These devices support Timer 4 */
#if defined (tmr_v1_2) || defined (LIB_BUILD)

/*******************************************************************************
Function Prototype : void OpenTimer4(unsigned int config,unsigned int period)
 
Include            : timer.h
 
Description        : This function configures the 16-bit timer module.
 
Arguments          : config - This contains the parameters to be configured in
                     the T4CON register as defined below
					 
			Timer Module On/Off						
			   *	T4_ON						
			   *	T4_OFF						
			Timer Module Idle mode On/Off						
			   *	T4_IDLE_CON						
			   *	T4_IDLE_STOP						
			Timer Gate time accumulation enable						
			   *	T4_GATE_ON						
			   *	T4_GATE_OFF						
			Timer prescaler						
			   *	T4_PS_1_1						
			   *	T4_PS_1_8						
			   *	T4_PS_1_64						
			   *	T4_PS_1_256						
			Timer 32bit mode enable/disable						
			   *	T4_32BIT_MODE_ON						
			   *	T4_32BIT_MODE_OFF						
			Timer clock source						
			   *	T4_SOURCE_EXT						
			   *	T4_SOURCE_INT						
			   
		  period - This contains the period match value to be stored 
		  into the PR register 
 
Return Value      : None
 
Remarks           : This function configures the 16-bit Timer Control register and 
                    sets the period match value into the PR register. 
**********************************************************************************/

void OpenTimer4(unsigned int config,unsigned int period)
{
    TMR4  = 0;          /* Reset Timer4 to 0x0000 */
    PR4   = period;     /* assigning Period to Timer period register */
    T4CON = config;     /* configure timer control reg */
    T4CONbits.T32 = 0;
}

#else
#warning "Does not build on this target"
#endif
