 
#include "uart.h"

#if defined (uart_v1_1) || defined (uart_v1_2) || defined (LIB_BUILD)
/**********************************************************************
Function Prototype : void ConfigIntUART2(unsigned int config)

Include            : uart.h
 
Description        : This function configures the UART Interrupts.
 
Arguments          : config - Individual interrupt enable/disable information 
                     as defined below
					 
		 Receive Interrupt enable					
			*	UART_RX_INT_EN					
			*	UART_RX_INT_DIS					
		 Receive Interrupt Priority					
			*	UART_RX_INT_PR0					
			*	UART_RX_INT_PR1				
			*	UART_RX_INT_PR2					
			*	UART_RX_INT_PR3					
			*	UART_RX_INT_PR4					
			*	UART_RX_INT_PR5					
			*	UART_RX_INT_PR6					
			*	UART_RX_INT_PR7					
		 Transmit Interrupt enable					
			*	UART_TX_INT_EN					
			*	UART_TX_INT_DIS					
		 Transmit Interrupt Priority					
			*	UART_TX_INT_PR0					
			*	UART_TX_INT_PR1					
			*	UART_TX_INT_PR2					
			*	UART_TX_INT_PR3					
			*	UART_TX_INT_PR4					
			*	UART_TX_INT_PR5					
			*	UART_TX_INT_PR6					
			*	UART_TX_INT_PR7
 
Return Value       : None
 
Remarks            : This function enables/disables the UART transmit and
                     receive interrupts and sets the interrupt priorities.
**********************************************************************/
void ConfigIntUART2(unsigned int config)
{
    /* clear IF flags */
    IFS1bits.U2RXIF = 0;
    IFS1bits.U2TXIF = 0;

    /* set priority */
    IPC7bits.U2RXIP = 0x0007 & config;
    IPC7bits.U2TXIP = (0x0070 & config) >> 4;

    /* enable/disable interrupt */
    IEC1bits.U2RXIE = (0x0008 & config) >> 3;
    IEC1bits.U2TXIE = (0x0080 & config) >> 7;
}

#else
#warning "Does not build on this target"
#endif
