 
#include "uart.h"

/* UART4 is defined in following devices */
#if defined (uart_v1_2) || defined (LIB_BUILD)

/***************************************************************************************
Function Prototype : unsigned int getsUART4(unsigned int length,unsigned int *buffer,
                                            unsigned int uart_data_wait)

Include            : uart.h
 
Description        : This function reads a string of data of specified length and 
                     stores it into the buffer location specified.
 
Arguments          : length - This is the length of the string to be received.
                     buffer - This is the pointer to the location where the data 
                     received  have to be stored.
                     uart_data_wait- This is the time-out count for which the module
                     has to wait before return. If the time-out count is N, the actual
                     time out would be about (19 * N  1) instruction cycles.
 
Return Value       : This function returns the number of bytes yet to be received.
                     If the return value is 0, it indicates that the complete string 
                     has been received. If the return value is non-zero, it indicates that
                     the complete string has not been received
 
Remarks            : None
*******************************************************************************************/

unsigned int getsUART4(unsigned int length,unsigned int *buffer,
                       unsigned int uart_data_wait)

{
    int wait = 0;
    char *temp_ptr = (char *) buffer;

    while(length)                         /* read till length is 0 */
    {
        while(!DataRdyUART4())
        {
            if(wait < uart_data_wait)
                wait++ ;                  /*wait for more data */
            else
                return(length);           /*Time out- Return words/bytes to be read */
        }
        wait=0;
        if(U4MODEbits.PDSEL == 3)         /* check if TX/RX is 8bits or 9bits */
            *buffer++ = U4RXREG;          /* data word from HW buffer to SW buffer */
	else
            *temp_ptr++ = U4RXREG & 0xFF; /* data byte from HW buffer to SW buffer */

        length--;
    }

    return(length);                       /* number of data yet to be received i.e.,0 */
}

#else
#warning "Does not build on this target"
#endif
