 
#include "uart.h"

/* UART2 is defined in following devices */
#if defined (uart_v1_1) || defined (uart_v1_2) || defined (LIB_BUILD)

/*********************************************************************************************
Function Prototype  : void putsUART2(unsigned int *buffer)
 
Include             : uart.h
 
Description         : This function writes a string of data to be transmitted 
                      into the UART transmit buffer.
 
Arguments           : buffer - This is the pointer to the string of data to be transmitted.
 
Return Value        : None
 
Remarks             : This function writes the data to be transmitted into the transmit buffer
                      until NULL character is encountered. Once the transmit buffer is full, 
                      it waits until data gets transmitted and then writes the next data into 
                      the Transmit register.
************************************************************************************************/
void putsUART2(unsigned int *buffer)
{
    char * temp_ptr = (char *) buffer;

    /* transmit till NULL character is encountered */

    if(U2MODEbits.PDSEL == 3)        /* check if TX is 8bits or 9bits */
    {
        while(*buffer != '\0') 
        {
            while(U2STAbits.UTXBF); /* wait if the buffer is full */
            U2TXREG = *buffer++;    /* transfer data word to TX reg */
        }
    }
    else
    {
        while(*temp_ptr != '\0')
        {
            while(U2STAbits.UTXBF);  /* wait if the buffer is full */
            U2TXREG = *temp_ptr++;   /* transfer data byte to TX reg */
        }
    }
}

#else
#warning "Does not build on this target"
#endif
